"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.zip = zip;
exports.generateUtility = generateUtility;

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) { return; } var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

/**
 * Combines every list in $lists into a single list of sub-lists.
 * Each element in the returned list contains all the elements at that position in $lists. The returned list is as long as the shortest list in $lists.
 * The returned list is always comma-separated and the sub-lists are always space-separated.
 * This is a rewrite of zip scss function (see: https://sass-lang.com/documentation/modules/list#zip)
 * @param list
 * @returns {[]}
 * @example
 * zip(['10px', '50px', '100px'], ['short', 'mid']); // [['10px', 'short'], ['50px', 'mid']]
 */
function zip() {
  var shortest = 0;

  for (var _len = arguments.length, list = new Array(_len), _key = 0; _key < _len; _key++) {
    list[_key] = arguments[_key];
  }

  list.forEach(function (l) {
    if (l instanceof Array) {
      if (!shortest || l.length < shortest) {
        shortest = l.length;
      }
    }
  });
  var res = [];

  var _loop = function _loop(i) {
    res[i] = [];
    var ind = 0;
    list.forEach(function (l) {
      res[i][ind] = l[i];
      ind += 1;
    });
  };

  for (var i = 0; i < shortest; i += 1) {
    _loop(i);
  }

  return res;
}
/**
 * Utility generator
 * Used to generate utilities & print utilities
 * @param {object} $utility - an utility object to process
 * @param {string} [$infix=""] - infix (eg: -media, -sm, -md, ...)
 * @returns {string} css - the css for utilities
 */


function generateUtility(_ref) {
  var $utility = _ref.$utility,
      _ref$$infix = _ref.$infix,
      $infix = _ref$$infix === void 0 ? '' : _ref$$infix;
  var values = $utility.values;

  if (values instanceof Array) {
    values = zip(values, values);
  }

  var classList = []; // eslint-disable-next-line no-restricted-syntax

  var _iteratorNormalCompletion = true;
  var _didIteratorError = false;
  var _iteratorError = undefined;

  try {
    var _loop2 = function _loop2() {
      var _step$value = _slicedToArray(_step.value, 2),
          key = _step$value[0],
          value = _step$value[1];

      var properties = $utility.property; // Multiple properties are possible, for example with vertical or horizontal margins or paddings

      if (typeof properties === 'string') {
        properties = [properties];
      }

      var propertyClass = $utility.hasOwnProperty('class') ? $utility.class : properties[0];
      propertyClass = !propertyClass ? '' : propertyClass;
      var infix = propertyClass === '' && $infix[0] === '-' ? $infix.slice(1) : $infix; // Don't prefix if value key is null (eg. with shadow class)
      // eslint-disable-next-line no-nested-ternary

      var propertyClassModifier = key ? (propertyClass === '' && infix === '' ? '' : '-') + key : '';
      classList.push(".".concat(propertyClass).concat(infix).concat(propertyClassModifier, " {\n      ").concat(properties.map(function (property) {
        return "".concat(property, ": ").concat(value, " !important;");
      }).join('\n'), "\n    }"));
    };

    for (var _iterator = values[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
      _loop2();
    }
  } catch (err) {
    _didIteratorError = true;
    _iteratorError = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion && _iterator.return != null) {
        _iterator.return();
      }
    } finally {
      if (_didIteratorError) {
        throw _iteratorError;
      }
    }
  }

  return classList.join('\n');
}